@@ -35,6 +35,8 @@ def get_renderer(field, translate):
             return DateFieldRenderer(field, translate)
         elif renderer.render_type == "password":
             return PasswordFieldRenderer(field, translate)
+        elif renderer.render_type == "hidden":
+            return HiddenFieldRenderer(field, translate)
     else:
         # Try to determine the datatype of the field and set approriate
         # renderer.
@@ -128,9 +130,10 @@ class FormRenderer(Renderer):
         html = []
         html.append('<div class="row row-fluid">')
         if len(self._form._config.get_pages()) > 0:
-            html.append('<div class="col-md-9 col-md-offset-3 offset3 span9 button-pane well-small">')
+            html.append('<div class="col-sm-3 span3 button-pane"></div>')
+            html.append('<div class="col-sm-9 span9 button-pane">')
         else:
-            html.append('<div class="col-md-12 span12 button-pane well-small">')
+            html.append('<div class="col-sm-12 span12 button-pane well-small">')
         html.append('<button type="submit" '
                     'class="btn btn-default">%s</button>' % 'Submit')
         html.append('<button type="reset" '
@@ -192,7 +195,8 @@ class FieldRenderer(Renderer):
         # TODO: Split rendering in four parts: label, fieldbody, errors,
         # help. Each in its own template.
         html = []
-        html.append('<div class="form-group">')
+        has_errors = len(self._field.get_errors())
+        html.append('<div class="form-group %s">' % (has_errors and 'has-error'))
         html.append(self._render_label())
         values = self._get_template_values()
         html.append(self.template.render(**values))
@@ -254,6 +258,19 @@ class PasswordFieldRenderer(FieldRenderer):
         FieldRenderer.__init__(self, field, translate)
         self.template = template_lookup.get_template("password.mako")
 
+class HiddenFieldRenderer(FieldRenderer):
+    """A Renderer to render hidden elements"""
+
+    def __init__(self, field, translate):
+        FieldRenderer.__init__(self, field, translate)
+        self.template = template_lookup.get_template("hidden.mako")
+
+    def render(self):
+        html = []
+        values = self._get_template_values()
+        html.append(self.template.render(**values))
+        return "".join(html)
+
 
 # TODO: Use a new superclass for the following two renderers as they
 # deal not only with one single value but with multiple selectable
